package com.tzld.longarticle.recommend.server.service.recommend;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.ctrip.framework.apollo.spring.annotation.ApolloJsonValue;
import com.tzld.longarticle.recommend.server.common.enums.aigc.PublishContentStatusEnum;
import com.tzld.longarticle.recommend.server.common.enums.longArticle.ArticleVideoAuditStatusEnum;
import com.tzld.longarticle.recommend.server.common.enums.recommend.ContentPoolEnum;
import com.tzld.longarticle.recommend.server.mapper.aigc.AigcBaseMapper;
import com.tzld.longarticle.recommend.server.mapper.aigc.PublishContentMapper;
import com.tzld.longarticle.recommend.server.mapper.longArticle.ArticleAuditMapper;
import com.tzld.longarticle.recommend.server.model.dto.PublishContentMiniprogramDTO;
import com.tzld.longarticle.recommend.server.model.entity.aigc.ProducePlanExeRecord;
import com.tzld.longarticle.recommend.server.model.entity.longArticle.*;
import com.tzld.longarticle.recommend.server.model.param.videoAudit.*;
import com.tzld.longarticle.recommend.server.model.vo.ArticleVideoAuditListVO;
import com.tzld.longarticle.recommend.server.repository.aigc.ProducePlanExeRecordRepository;
import com.tzld.longarticle.recommend.server.repository.longArticle.*;
import com.tzld.longarticle.recommend.server.util.DateUtils;
import com.tzld.longarticle.recommend.server.util.RedisUtil;
import com.tzld.longarticle.recommend.server.util.page.Page;
import com.xxl.job.core.biz.model.ReturnT;
import com.xxl.job.core.handler.annotation.XxlJob;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections4.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import java.util.*;
import java.util.concurrent.TimeUnit;
import java.util.stream.Collectors;

@Service
@Slf4j
public class ArticleVideoAuditService {

    @Autowired
    private AigcBaseMapper aigcBaseMapper;
    @Autowired
    private ArticleAuditMapper articleAuditMapper;
    @Autowired
    private PublishContentMapper publishContentMapper;
    @Autowired
    private ArticleReMatchRecordRepository articleReMatchRecordRepository;
    @Autowired
    private LongArticleCrawlerVideoRepository crawlerVideoRepository;
    @Autowired
    private LongArticleTitleAuditRepository titleAuditRepository;
    @Autowired
    private LongArticlesMatchVideoRepository articlesMatchVideoRepository;
    @Autowired
    private ArticleAuditService articleAuditService;
    @Autowired
    private ProducePlanExeRecordRepository producePlanExeRecordRepository;
    @Autowired
    private ArticlePoolPromotionSourceRepository articlePoolPromotionSourceRepository;
    @Autowired
    private RedisUtil redisUtil;

    @Autowired
    private RedisTemplate<String, String> redisTemplate;

    @Value("${cdnUrl:https://rescdn.piaoquantv.com/}")
    private String cdnUrl;

    @Value("${videoAudit.poolLevel.sort:}")
    private String poolLevelDesc;

    @ApolloJsonValue("${daily.article.audit.pool.count.config:{}}")
    private Map<String, Integer> dailyAuditPoolCount;

    public Page<ArticleVideoAuditListVO> list(ArticleVideoAuditListParam param) {
        int offset = (param.getPageNum() - 1) * param.getPageSize();
        int count = articleAuditMapper.articleVideoAuditListCount(param.getContentId(), param.getStatus(),
                param.getTitle(), param.getAuditAccount(), param.getSourceProducePlan(), param.getFlowPoolLevel(), param.getAuditTimestamp());
        List<ArticleVideoAuditListVO> list = articleAuditMapper.articleVideoAuditList(param.getContentId(),
                param.getStatus(), param.getTitle(), param.getAuditAccount(), param.getSourceProducePlan()
                , param.getFlowPoolLevel(), param.getAuditTimestamp(), offset, param.getPageSize(), poolLevelDesc);
        buildArticleVideoAuditListVO(list);
        Page<ArticleVideoAuditListVO> page = new Page<>(param.getPageNum(), param.getPageSize());
        page.setTotalSize(count);
        page.setObjs(list);
        return page;
    }

    private void buildArticleVideoAuditListVO(List<ArticleVideoAuditListVO> list) {
        if (CollectionUtils.isEmpty(list)) {
            return;
        }
        List<String> contentIds = list.stream().map(ArticleVideoAuditListVO::getContentId).collect(Collectors.toList());
        List<LongArticleCrawlerVideo> videoList = crawlerVideoRepository.getByContentIdIn(contentIds);
        Map<String, List<LongArticleCrawlerVideo>> videoMap = videoList.stream()
                .filter(o -> o.getDownloadStatus() == 2)
                .collect(Collectors.groupingBy(LongArticleCrawlerVideo::getContentId));
        for (ArticleVideoAuditListVO item : list) {
            List<LongArticleCrawlerVideo> videos = videoMap.get(item.getContentId());
            if (CollectionUtils.isEmpty(videos)) {
                continue;
            }
            List<ArticleVideoAuditListVO.VideoItem> videoItems = videos.stream().map(video -> {
                ArticleVideoAuditListVO.VideoItem videoItem = new ArticleVideoAuditListVO.VideoItem();
                videoItem.setVideoId(video.getId());
                videoItem.setTitle(item.getKimiTitle());
                videoItem.setVideoUrl(cdnUrl + video.getVideoOssPath());
                if (StringUtils.hasText(video.getCoverOssPath())) {
                    videoItem.setCoverUrl(cdnUrl + video.getCoverOssPath());
                } else {
                    videoItem.setCoverUrl(video.getCoverUrl());
                }
                videoItem.setStatus(video.getStatus());
                videoItem.setAuditAccount(video.getAuditAccount());
                videoItem.setAuditTimestamp(video.getAuditTimestamp());
                return videoItem;
            }).collect(Collectors.toList());
            item.setVideoList(videoItems);
            item.setVideoCount(videoItems.size());
            item.setWaitingAuditVideoCount((int) videoItems.stream().filter(o -> o.getStatus() == 0).count());
        }
    }

    public Page<ArticleVideoAuditListVO> next(ArticleVideoAuditListParam param) {
        Page<ArticleVideoAuditListVO> result = new Page<>();

        String lockKey = "article-pool-audit-lock";
        String requestId = UUID.randomUUID().toString();
        int retryCount = 0;
        boolean lockAcquired = false;

        // 尝试获取分布式锁，最多重试10次，每次间隔200ms
        while (retryCount < 10) {
            lockAcquired = redisUtil.tryAcquireLock(lockKey, requestId);
            if (lockAcquired) {
                break;
            }
            retryCount++;
            try {
                Thread.sleep(200); // 等待200ms后重试
            } catch (InterruptedException e) {
                Thread.currentThread().interrupt();
                return result; // 返回空结果
            }
        }

        if (!lockAcquired) {
            return result; // 返回空结果
        }

        long now = System.currentTimeMillis();
        String id;
        String inAuditListRedisKey = "article-pool-in-audit-list";
        ArticleVideoAuditListVO item = null;
        try {
            String dateStr = DateUtils.getCurrentDateStr("yyyyMMdd");
            String auditQueueRedisKey = "article-pool-audit-queue-" + dateStr;
            // 从待审核队列中获取数据，如未获取到则从数据库查询一条
            Long size = redisTemplate.opsForZSet().size(auditQueueRedisKey);
            if (Objects.isNull(size) || size == 0) {
                List<String> entries = redisTemplate.opsForList().range(inAuditListRedisKey, 0, -1);
                List<String> excludeContentIds = new ArrayList<>();
                if (CollectionUtils.isNotEmpty(entries)) {
                    excludeContentIds = entries.stream().map(o -> {
                        JSONObject json = JSONObject.parseObject(o);
                        return json.getString("id");
                    }).collect(Collectors.toList());
                }
                item = articleAuditMapper.articleVideoAuditNext(param.getContentId(),
                        param.getStatus(), param.getTitle(), param.getAuditAccount(), param.getSourceProducePlan(),
                        null, excludeContentIds);
            } else {
                // 从待审核队列中获取数据, 如获取到的内容已审核，则重新获取
                while (true) {
                    Set<String> ids = redisTemplate.opsForZSet().reverseRangeByScore(auditQueueRedisKey, 0, 100, 0, 1);
                    if (CollectionUtils.isNotEmpty(ids)) {
                        id = ids.iterator().next();
                        redisTemplate.opsForZSet().remove(auditQueueRedisKey, id);
                        item = articleAuditMapper.articleVideoAuditNext(Arrays.asList(id), null, null,
                                null, null, null, null);
                        if (item.getStatus() == ArticleVideoAuditStatusEnum.WAITING.getCode()) {
                            break;
                        }
                    } else {
                        break;
                    }
                }
            }
        } finally {
            // 释放锁
            redisUtil.releaseLock(lockKey, requestId);
        }
        if (Objects.isNull(item)) {
            return result;
        }

        // 添加到超时队列
        JSONObject json = new JSONObject();
        json.put("id", item.getContentId());
        json.put("timestamp", now + (15 * 60 * 1000));
        redisTemplate.opsForList().rightPush(inAuditListRedisKey, json.toJSONString());
        List<ArticleVideoAuditListVO> list = Collections.singletonList(item);
        buildArticleVideoAuditListVO(list);
        result.setObjs(list);
        return result;
    }

    public void auditArticle(ArticleAuditParam param) {
        LongArticleTitleAudit titleAudit = titleAuditRepository.getByContentId(param.getContentId());
        Long now = System.currentTimeMillis();
        titleAudit.setStatus(param.getStatus());
        titleAudit.setAuditAccount(param.getAuditAccount());
        titleAudit.setAuditTimestamp(now);
        titleAuditRepository.save(titleAudit);
        if (param.getStatus() == 2) {
            // 审核不通过
            auditArticleReject(titleAudit);
        } else {
            // 审核通过
            auditArticlePass(titleAudit);
        }
        // 当日审核数+1
        addAuditCount(titleAudit.getFlowPoolLevel());
    }

    private void addAuditCount(String poolLevel) {
        String dateStr = DateUtils.getCurrentDateStr("yyyyMMdd");
        String key = "article_audit_count_" + dateStr + "_" + poolLevel;
        int totalCount = Integer.parseInt(Optional.ofNullable(redisTemplate.opsForValue().get(key)).orElse("0"));
        redisTemplate.opsForValue().set(key, String.valueOf(totalCount + 1), 24, TimeUnit.HOURS);
    }

    private void auditArticlePass(LongArticleTitleAudit titleAudit) {
        // publish_content
        publishContentMapper.updatePublishContentStatus(titleAudit.getContentId(),
                PublishContentStatusEnum.waiting_publish.getVal(),
                PublishContentStatusEnum.gzh_article_deprecated.getVal());
    }

    private void auditArticleReject(LongArticleTitleAudit titleAudit) {
        // reMatch 暂时取消
//        List<LongArticleCrawlerVideo> videoList = crawlerVideoRepository.getByContentIdAndIsIllegal(titleAudit.getContentId(), 1);
//        if (CollectionUtils.isNotEmpty(videoList)) {
//            for (LongArticleCrawlerVideo video : videoList) {
//                ArticleReMatchRecord reMatchRecord = new ArticleReMatchRecord();
//                reMatchRecord.setContentId(titleAudit.getContentId());
//                reMatchRecord.setOssPath(video.getVideoOssPath());
//                reMatchRecord.setStatus(0);
//                reMatchRecord.setCreateTimestamp(System.currentTimeMillis() / 1000);
//                articleReMatchRecordRepository.save(reMatchRecord);
//            }
//        }
        // publish_content
        publishContentMapper.updatePublishContentStatus(titleAudit.getContentId(),
                PublishContentStatusEnum.gzh_article_deprecated.getVal(),
                PublishContentStatusEnum.waiting_publish.getVal());
    }

    public void auditVideo(VideoAuditParam param) {
        LongArticleCrawlerVideo video = crawlerVideoRepository.getById(param.getVideoId());
        Long now = System.currentTimeMillis();
        video.setStatus(param.getStatus());
        video.setAuditAccount(param.getAuditAccount());
        video.setAuditTimestamp(now);
        if (param.getStatus() == 2) {
            video.setIsIllegal(1);
            // 审核不通过
            auditVideoReject(video);
            updateRootContentVideo(param.getContentId(), video);
        } else {
            video.setIsIllegal(0);
        }
        crawlerVideoRepository.save(video);
    }

    private void updateRootContentVideo(String contentId, LongArticleCrawlerVideo video) {
        ProducePlanExeRecord content = producePlanExeRecordRepository.getByPlanExeId(contentId);
        if (Objects.isNull(content)) {
            return;
        }
        ArticlePoolPromotionSource source = articlePoolPromotionSourceRepository.getByChannelContentId(content.getChannelContentId());
        if (Objects.isNull(source)) {
            return;
        }
        String rootProduceContentId = source.getRootProduceContentId();
        List<LongArticleCrawlerVideo> crawlerVideoList = crawlerVideoRepository.getByContentId(rootProduceContentId);
        if (CollectionUtils.isEmpty(crawlerVideoList)) {
            return;
        }
        for (LongArticleCrawlerVideo crawlerVideo : crawlerVideoList) {
            if (!crawlerVideo.getVideoTitle().equals(video.getVideoTitle())) {
                continue;
            }
            crawlerVideo.setIsIllegal(video.getIsIllegal());
            crawlerVideoRepository.save(crawlerVideo);
        }
    }

    private void auditVideoReject(LongArticleCrawlerVideo video) {
        // 已发布文章删除
        List<LongArticlesMatchVideo> matchVideos = articlesMatchVideoRepository.getByContentId(video.getContentId());
        List<String> traceIds = new ArrayList<>();
        if (CollectionUtils.isNotEmpty(matchVideos)) {
            for (LongArticlesMatchVideo matchVideo : matchVideos) {
                // 发布位置为头条
                List<String> results = JSONArray.parseArray(matchVideo.getResponse(), String.class);
                if (CollectionUtils.isNotEmpty(results) && results.get(0).contains(video.getVideoOssPath())) {
                    traceIds.add(matchVideo.getTraceId());
                }
            }
        }
        if (CollectionUtils.isEmpty(traceIds)) {
            return;
        }
        List<PublishContentMiniprogramDTO> publishContents = publishContentMapper.getPublishContentByTraceIdIn(traceIds);
        List<String> publishContentIds = publishContents.stream().map(PublishContentMiniprogramDTO::getPublishContentId)
                .collect(Collectors.toList());
        articleAuditService.buildArticleAuditDelete(publishContentIds, "视频审核不通过删除");
    }

    public List<Object> getFilterValue(AuditFilterParam param) {
        String itemName = param.getItemName();
        if ("contentId".equals(itemName) || "title".equals(itemName) || "auditAccount".equals(itemName)) {
            return articleAuditMapper.searchFilterValueByItemName(itemName, param.getSearchKeyword())
                    .stream().collect(Collectors.toList());
        } else if ("sourceProducePlan".equals(itemName)) {
            List<String> planIds = articleAuditMapper.searchFilterValueByItemName(itemName, null);
            return aigcBaseMapper.articleVideoAuditPlanFilterValue(planIds, param.getSearchKeyword())
                    .stream().collect(Collectors.toList());
        } else {
            return new ArrayList<>();
        }
    }

    @XxlJob("rematchVideoAudit")
    public ReturnT<String> rematchVideoAudit(String param) {
        List<LongArticleTitleAudit> rejectList = titleAuditRepository.getByStatus(ArticleVideoAuditStatusEnum.REJECT.getCode());
        if (CollectionUtils.isEmpty(rejectList)) {
            return ReturnT.SUCCESS;
        }
        List<String> contentIds = rejectList.stream().map(LongArticleTitleAudit::getContentId).collect(Collectors.toList());
        List<ArticleReMatchRecord> reMatchRecordList = articleReMatchRecordRepository.getByContentIdIn(contentIds);
        if (CollectionUtils.isEmpty(reMatchRecordList)) {
            return ReturnT.SUCCESS;
        }
        Map<String, List<ArticleReMatchRecord>> reMatchRecordMap = reMatchRecordList.stream()
                .collect(Collectors.groupingBy(ArticleReMatchRecord::getContentId));
        for (LongArticleTitleAudit audit : rejectList) {
            List<ArticleReMatchRecord> records = reMatchRecordMap.get(audit.getContentId());
            if (CollectionUtils.isEmpty(records)) {
                continue;
            }
            records = records.stream().filter(o -> Objects.isNull(o.getTraceId())).collect(Collectors.toList());
            if (CollectionUtils.isEmpty(records)) {
                continue;
            }
            List<ArticleReMatchRecord> failList = records.stream()
                    .filter(o -> o.getStatus().equals(2) || o.getStatus().equals(0)).collect(Collectors.toList());
            if (CollectionUtils.isNotEmpty(failList)) {
                continue;
            }
            audit.setStatus(ArticleVideoAuditStatusEnum.WAITING.getCode());
            titleAuditRepository.save(audit);
        }
        return ReturnT.SUCCESS;
    }

    public void updateArticleTitle(ArticleTitleUpdateParam param) {
        long now = System.currentTimeMillis();
        articleAuditMapper.updateArticleTitle(param, now);
    }

    public void updateVideoTitle(VideoTitleUpdateParam param) {
        long now = System.currentTimeMillis();
        articleAuditMapper.updateVideoTitle(param, now);
    }

    @XxlJob("shuffleAuditGroup")
    public ReturnT<String> shuffleAuditGroup(String param) {
        List<String> auditUser = Arrays.asList("a", "b", "c", "d", "e", "f", "g", "h", "i", "j");
        List<LongArticleTitleAudit> contentIds = titleAuditRepository.getByStatus(ArticleVideoAuditStatusEnum.WAITING.getCode());
        for (int i = 0; i < contentIds.size(); i++) {
            int per = i % auditUser.size();
            LongArticleTitleAudit audit = contentIds.get(i);
            audit.setAuditAccount(auditUser.get(per));
            titleAuditRepository.save(audit);
        }
        return ReturnT.SUCCESS;
    }

    public void addAudit(ArticleVideoAuditAddAuditParam param) {
        ProducePlanExeRecord exeRecord = producePlanExeRecordRepository.getByPlanExeId(param.getContentId());
        List<String> auditUser = Arrays.asList("a", "b", "c", "d", "e", "f", "g", "h", "i", "j");
        Random random = new Random();
        int index = random.nextInt(auditUser.size());
        String auditAccount = auditUser.get(index);
        int status = ArticleVideoAuditStatusEnum.WAITING.getCode();
        if (!Objects.equals(param.getFlowPoolLevel(), ContentPoolEnum.autoArticlePoolLevel4.getContentPool())) {
            if (Objects.nonNull(exeRecord)) {
                String channelContentId = exeRecord.getChannelContentId();
                ArticlePoolPromotionSource source = articlePoolPromotionSourceRepository.getByChannelContentId(channelContentId);
                if (Objects.nonNull(source) && source.getStatus() == 1 && source.getDeleted() == 0) {
                    status = ArticleVideoAuditStatusEnum.PASS.getCode();
                    auditAccount = "sys";
                }
            }
        }
        LongArticleTitleAudit item = new LongArticleTitleAudit();
        item.setContentId(param.getContentId());
        item.setStatus(status);
        item.setFlowPoolLevel(param.getFlowPoolLevel());
        item.setCreateTimestamp(System.currentTimeMillis());
        if (Objects.nonNull(exeRecord)) {
            item.setProducePlanId(exeRecord.getPlanId());
        }
        item.setAuditAccount(auditAccount);
        titleAuditRepository.save(item);
    }

    @XxlJob("articlePoolAuditQueueJob")
    public ReturnT<String> articlePoolAuditQueueJob(String param) {
        String lockKey = "article-pool-audit-queue-job-lock";
        String requestId = UUID.randomUUID().toString();
        Boolean lockAcquired = redisUtil.tryAcquireLock(lockKey, requestId);
        if (!lockAcquired) {
            return ReturnT.SUCCESS;
        }
        try {
            Long now = System.currentTimeMillis();
            String dateStr = DateUtils.getCurrentDateStr("yyyyMMdd");
            String inAuditListRedisKey = "article-pool-in-audit-list";
            String auditQueueRedisKey = "article-pool-audit-queue-" + dateStr;
            // 判断是否审核超时，重新加入待审核队列
            while (true) {
                List<String> inAuditList = redisTemplate.opsForList().range(inAuditListRedisKey, 0, 0);
                if (CollectionUtils.isEmpty(inAuditList)) {
                    break;
                }
                JSONObject firstObj = JSONObject.parseObject(inAuditList.get(0));
                if (now > firstObj.getLong("timestamp")) {
                    redisTemplate.opsForList().leftPop(inAuditListRedisKey);
                    String id = firstObj.getString("id");
                    LongArticleTitleAudit videoAudit = titleAuditRepository.getByContentId(id);
                    if (videoAudit.getStatus() == ArticleVideoAuditStatusEnum.WAITING.getCode()) {
                        ContentPoolEnum poolEnum = ContentPoolEnum.from(videoAudit.getFlowPoolLevel());
                        redisTemplate.opsForZSet().add(auditQueueRedisKey, id, poolEnum.getWeight());
                    }
                } else {
                    break;
                }
            }
            List<String> excludeContentIds = new ArrayList<>();
            // 审核中列表获取，按内容池分组
            List<String> inAuditList = redisTemplate.opsForList().range(inAuditListRedisKey, 0, -1);
            Map<String, List<LongArticleTitleAudit>> inAuditListPoolCountMap = new HashMap<>();
            if (CollectionUtils.isNotEmpty(inAuditList)) {
                List<String> inAuditListIds = inAuditList.stream().map(item -> JSONObject.parseObject(item).getString("id")).collect(Collectors.toList());
                List<LongArticleTitleAudit> auditQueueList = titleAuditRepository.getByContentIdIn(new ArrayList<>(inAuditListIds));
                inAuditListPoolCountMap = auditQueueList.stream().collect(Collectors.groupingBy(item -> ContentPoolEnum.from(item.getFlowPoolLevel()).getContentPool()));
                excludeContentIds.addAll(inAuditListIds);
            }
            // 待审核列表获取，按内容池分组
            Set<String> auditQueueIds = redisTemplate.opsForZSet().rangeByScore(auditQueueRedisKey, 0, 100);
            Map<String, List<LongArticleTitleAudit>> auditQueuePoolCountMap = new HashMap<>();
            if (CollectionUtils.isNotEmpty(auditQueueIds)) {
                List<LongArticleTitleAudit> auditQueueList = titleAuditRepository.getByContentIdIn(new ArrayList<>(auditQueueIds));
                auditQueuePoolCountMap = auditQueueList.stream().collect(Collectors.groupingBy(item -> ContentPoolEnum.from(item.getFlowPoolLevel()).getContentPool()));
                excludeContentIds.addAll(auditQueueIds);
            }
            // 每日配置发送量不足添加
            for (Map.Entry<String, Integer> entry : dailyAuditPoolCount.entrySet()) {
                ContentPoolEnum poolEnum = ContentPoolEnum.from(entry.getKey());
                String key = "article_audit_count_" + dateStr + "_" + poolEnum.getContentPool();
                int totalCount = Integer.parseInt(Optional.ofNullable(redisTemplate.opsForValue().get(key)).orElse("0"));
                if (totalCount < entry.getValue()) {
                    List<LongArticleTitleAudit> auditQueueList = auditQueuePoolCountMap.getOrDefault(poolEnum.getContentPool(), new ArrayList<>());
                    List<LongArticleTitleAudit> inAuditListPool = inAuditListPoolCountMap.getOrDefault(poolEnum.getContentPool(), new ArrayList<>());
                    int needCount = entry.getValue() - (totalCount + auditQueueList.size() + inAuditListPool.size());
                    if (needCount > 0) {
                        List<ArticleVideoAuditListVO> addList = articleAuditMapper.articleVideoWatingAuditList(
                                Arrays.asList(ArticleVideoAuditStatusEnum.WAITING.getCode()),
                                Arrays.asList(poolEnum.getContentPool()), excludeContentIds, needCount);
                        if (CollectionUtils.isNotEmpty(addList)) {
                            for (ArticleVideoAuditListVO item : addList) {
                                redisTemplate.opsForZSet().add(auditQueueRedisKey, item.getContentId(), poolEnum.getWeight());
                                excludeContentIds.add(item.getContentId());
                            }
                        }
                    }
                }
            }
            // 待发布内容不足添加
            Long auditQueueSize = redisTemplate.opsForZSet().size(auditQueueRedisKey);
            if (Objects.isNull(auditQueueSize) || auditQueueSize < 20) {
                List<ArticleVideoAuditListVO> list = articleAuditMapper.articleVideoWatingAuditList(
                        Arrays.asList(ArticleVideoAuditStatusEnum.WAITING.getCode()), null, excludeContentIds, 40);
                if (CollectionUtils.isNotEmpty(list)) {
                    for (ArticleVideoAuditListVO item : list) {
                        ContentPoolEnum poolEnum = ContentPoolEnum.from(item.getFlowPoolLevel());
                        redisTemplate.opsForZSet().add(auditQueueRedisKey, item.getContentId(), poolEnum.getWeight());
                    }
                }
            }
            redisTemplate.expire(auditQueueRedisKey, 12, TimeUnit.HOURS);

        } finally {
            redisUtil.releaseLock(lockKey, requestId);
        }
        return ReturnT.SUCCESS;
    }
}
